@@ -43,7 +43,7 @@ import sys
 
 try:
     from .api import libmagick, library
-except ImportError:
+except ImportError:  # pragma: no cover
     libmagick = None
 from .compat import binary, string_type, text
 
@@ -59,7 +59,7 @@ __all__ = ('VERSION', 'VERSION_INFO', 'MAGICK_VERSION',
 #:
 #: .. versionchanged:: 0.1.9
 #:    Becomes :class:`tuple`.  (It was string before.)
-VERSION_INFO = (0, 5, 5)
+VERSION_INFO = (0, 5, 8)
 
 #: (:class:`basestring`) The version string e.g. ``'0.1.2'``.
 #:
@@ -101,7 +101,7 @@ if libmagick:
     #: .. versionadded:: 0.5.0
     if libmagick.GetMagickDelegates:  # pragma: no cover
         MAGICK_VERSION_DELEGATES = text(libmagick.GetMagickDelegates())
-    else:
+    else:  # pragma: no cover
         MAGICK_VERSION_DELEGATES = ""
 
     #: (:class:`basestring`) A string of all features enabled.
